==> haskell-githash-0.1.6.3-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-DWqYHMR0B9Z7LNUWgB0B63
key:                  githash-0.1.6.3-DWqYHMR0B9Z7LNUWgB0B63
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  6abce5a6ed7e928db13a96d4dd1c55f0
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-DWqYHMR0B9Z7LNUWgB0B63
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0 template-haskell-2.19.0.0
    th-compat-0.1.6-1jufj3sSjvQLQAnww3qayU

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-githash-0.1.6.3-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-7UB1Ol5wthF2b21t4PN0c2
key:                  githash-0.1.6.3-7UB1Ol5wthF2b21t4PN0c2
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  4cccca511743a475498df2be2074c1e8
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-7UB1Ol5wthF2b21t4PN0c2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0 template-haskell-2.19.0.0
    th-compat-0.1.6-A3UM6fgLRbT2XmXbqH9WgA

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
